#!/bin/sh

DIR="$1"
SERVERS_FILE="${DIR:+$DIR/}email-config.servers"

for SERVER in $(sort -u "$SERVERS_FILE")
do
	LOG="email-config.servers.log.$(echo $SERVER | sed -e 's,^{,,' -e 's,:,_,' -e 's,/.*,,')"

	echo "Testing server $SERVER"

	rm -fv $LOG.*

	# mailutil connects and sits at the username prompt.
	# 10 second timeout is long enough connect timeout.
	timeout -k 11 10 \
		stdbuf -o1 -e1 \
		mailutil check "$SERVER" \
		</dev/null >$LOG.mailutil 2>&1 &

	# php-imap connects and retries authentication with
	# failures (username/password) a few times, and some
	# providers delay failed authentication attempts by
	# a few seconds, seen up to 61 seconds delay/timeout.
	timeout -k 71 70 \
		stdbuf -o1 -e1 \
		php -r 'imap_open("'$SERVER'", "username", "password");' \
		</dev/null >$LOG.php-imap 2>&1 &

	sleep 1
done

echo 'Waiting threads to finish.'
wait
